class Anchor:
    anchor_rank__detail = {
        '直播时长(秒)': 'live_duration',
        '观看人数': 'watch_uv',
        '销售额': 'gmv',
        '小时成交额': 'hour_gmv',
        'UV价值': 'uv_value',
        '千川消耗(全域)': 'uni_cost',
        '有效金额(含优惠券)': 'doudian_coupon_validate_gmv',
        '成交订单数': 'pay_order_num',
        '平均在线': 'avg_online_uv',
        '转粉率': 'conversion_fans_rate',
        '观看次数': 'watch_pv',
        '平均停留时长(秒)': 'avg_watch_duration',
        '互动率(频次)': 'watch_interact_cnt_ratio',
        '新增粉丝数': 'incr_fans_num',
        '评论数': 'comment_num',
        '成交人数': 'pay_ucnt',
        '成交转化率(人数)': 'pay_uv_rate',
        '客单价': 'atv',
        'GPM': 'gpm',
        '成交转化率(人次)': 'pay_pv_rate',
        '成交转化率(商品)': 'pay_product_rate',
        '商品成交人数': 'product_pay_uv',
        '退款金额(店铺)': 'doudian_refund_order_amount',
        '退款订单数(店铺)': 'doudian_refund_order_num',
        '成交订单数(店铺)': 'doudian_pay_order_num',
        '全场ROI(店铺)': 'doudian_pay_order_gmv_qianchuan_cost_ratio',
        '有效ROI(店铺)': 'doudian_valid_roi',
        '退款占比(店铺)': 'doudian_refund_gmv_ratio',
        '成交订单金额(含优惠券)': 'doudian_coupon_gmv',
        '有效金额(店铺)': 'doudian_valid_amount',
        '成交订单金额(店铺)': 'doudian_pay_order_gmv',
        '退单占比(店铺)': 'doudian_refund_order_ratio',
        '退款金额(含优惠券)': 'doudian_coupon_refund_gmv',
        '有效ROI(含优惠券)': 'doudian_coupon_validate_gmv_qianchuan_cost_ratio',
        '全场ROI(含优惠券)': 'doudian_coupon_gmv_qianchuan_cost_ratio',
        '总投放消耗': 'sum_cost',
        '全场ROI(券)': 'total_live_coupon_roi',
        '全场ROI': 'total_roi',
        '优惠券金额(全域)': 'qianchuan_uni_pay_coupon_gmv',
        '总成交优惠券金额': 'qianchuan_sum_pay_coupon_gmv',
        '非千川流量转化率': 'un_qianchuan_flow_pay_ratio',
        '千川ROI(全域)': 'pay_uni_roi',
    }


class Dictionary:
    anchor = Anchor()
